@@ -10,7 +10,6 @@
 
 #include <KLocalizedString>
 #include <QUrl>
-#include <kcontacts_version.h>
 
 using namespace KAddressBookImportExport;
 
@@ -116,7 +115,7 @@ QString ContactFields::label(Field field)
         return i18n("Spouse");
     }
 
-    return QString();
+    return {};
 }
 
 ContactFields::Fields ContactFields::allFields()
@@ -166,23 +165,15 @@ void ContactFields::setValue(Field field, const QString &value, KContacts::Addre
         contact.insertCustom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-Anniversary"), value);
         break;
     case ContactFields::PreferredEmail: {
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-        contact.insertEmail(value, true);
-#else
         KContacts::Email email(value);
         email.setPreferred(true);
         contact.addEmail(email);
-#endif
         break;
     }
     case ContactFields::Email2:
     case ContactFields::Email3:
     case ContactFields::Email4:
-#if KContacts_VERSION < QT_VERSION_CHECK(5, 88, 0)
-        contact.insertEmail(value, false);
-#else
         contact.addEmail(KContacts::Email(value));
-#endif
         break;
     case ContactFields::Role:
         contact.setRole(value);
@@ -363,7 +354,7 @@ QString ContactFields::value(Field field, const KContacts::Addressee &contact)
 {
     switch (field) {
     case Undefined:
-        return QString();
+        return {};
     case FormattedName:
         return contact.formattedName();
     case Prefix:
@@ -383,7 +374,7 @@ QString ContactFields::value(Field field, const KContacts::Addressee &contact)
         if (birthday.date().isValid()) {
             return birthday.date().toString(Qt::ISODate);
         } else {
-            return QString();
+            return {};
         }
     }
     case Anniversary:
@@ -465,7 +456,7 @@ QString ContactFields::value(Field field, const KContacts::Addressee &contact)
         if (!emails.isEmpty()) {
             return emails.at(0);
         } else {
-            return QString();
+            return {};
         }
     }
     case Email2: {
@@ -473,7 +464,7 @@ QString ContactFields::value(Field field, const KContacts::Addressee &contact)
         if (emails.count() > 1) {
             return emails.at(1);
         } else {
-            return QString();
+            return {};
         }
     }
     case Email3: {
@@ -481,7 +472,7 @@ QString ContactFields::value(Field field, const KContacts::Addressee &contact)
         if (emails.count() > 2) {
             return emails.at(2);
         } else {
-            return QString();
+            return {};
         }
     }
     case Email4: {
@@ -489,7 +480,7 @@ QString ContactFields::value(Field field, const KContacts::Addressee &contact)
         if (emails.count() > 3) {
             return emails.at(3);
         } else {
-            return QString();
+            return {};
         }
     }
     case Mailer:
@@ -518,5 +509,5 @@ QString ContactFields::value(Field field, const KContacts::Addressee &contact)
         return contact.custom(QStringLiteral("KADDRESSBOOK"), QStringLiteral("X-SpousesName"));
     }
 
-    return QString();
+    return {};
 }
