@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,6 +33,4 @@ KAddressBookUserFeedbackProvider::KAddressBookUserFeedbackProvider(QObject *pare
     addDataSource(new KUserFeedback::LocaleInfoSource);
 }
 
-KAddressBookUserFeedbackProvider::~KAddressBookUserFeedbackProvider()
-{
-}
+KAddressBookUserFeedbackProvider::~KAddressBookUserFeedbackProvider() = default;
